@@ -104,8 +104,8 @@ setMethod("[",
               j <- T
             if (class(i) == "character") 
               stop("Not sure if these methods work for class character")
-            if (class(j) == "character") 
-              stop("Not sure if these methods work for class character")
+#            if (class(j) == "character") 
+#              stop("Not sure if these methods work for class character")
             callNextMethod(x = x, i = i, j = j, ...)
           })
 
@@ -171,4 +171,4 @@ setMethod("[<-", signature(x=".MoveTrack"), function(x, i, j,...,value) {
   d[i,j,...]<-value
   slot(x,'data')<-d
   return(x)
-})
\ No newline at end of file
+})
