@@ -10,7 +10,8 @@ test_that("print move",{
   data("leroy")
   expect_output(print(leroy), "class       : Move")
   expect_output(print(leroy), "sensors     : gps")
-  expect_output(print( burst(leroy, strftime(format="%m",timestamps( leroy)[-1]))),'bursts      : X02: 755, X03: 163')
+  expect_silent(t<-strftime(format="%m",timestamps( leroy)[-1]))
+  expect_output(print( burst(leroy, t)),sprintf('bursts      : X02: %i, X03: %i',table(t)[1],table(t)[2]))
   leroy@license<-"asdfasd"
   expect_output(print(leroy), "license     : asdfasd")
 
